@@ -192,12 +192,12 @@ start_and_monitor_long_task <- function(id,
     }
 
     args <- ExtendedTask_arguments
-    print(args)
-    save(args,
-      file = paste0(getwd(), "/arguments.rda")
-    )
+    #print(args)
+    #save(args,
+    #  file = paste0(getwd(), "/arguments.rda")
+    #)
     future::plan(future::multisession)
-    # future::plan(future::sequential)
+    #future::plan(future::sequential)
 
     # Start ExtendedTask
     CurrentTask <- NULL
