@@ -98,10 +98,13 @@ test_that("Masking Layer", {
   expect_equal(tensor_to_numpy(y[[1]]), tensor_to_numpy(example_tensor))
 
   # Check sequence length
-  expect_equal(as.numeric(tensor_to_numpy(y[[2]])), sequence_length)
+  expect_equal(as.numeric(tensor_to_numpy(py$get_SeqLen_from_mask(y[[2]]))), sequence_length)
 
   # Check Masking times
-  expect_equal(rowSums(tensor_to_numpy(y[[3]])), times - sequence_length)
+  expect_equal(rowSums(tensor_to_numpy(y[[2]])), times - sequence_length)
+
+  #Check Masking Features
+  expect_equal(rowSums(tensor_to_numpy(py$get_FeatureMask_from_mask(y[[2]],as.integer(features)))), (times - sequence_length)*features)
 })
 
 # Identity Layer----------------------------------------------------------------
@@ -123,23 +126,18 @@ test_that("identity layer", {
   layer <- py$identity_layer(apply_masking = FALSE)$to(device)
   y <- layer(
     x = values[[1]],
-    seq_len = values[[2]],
-    mask_times = values[[3]],
-    mask_features = values[[4]]
+    mask_times = values[[2]],
   )
 
   # Test that  values are the same
   expect_equal(tensor_to_numpy(y[[1]]), tensor_to_numpy(values[[1]]))
   expect_equal(tensor_to_numpy(y[[2]]), tensor_to_numpy(values[[2]]))
-  expect_equal(tensor_to_numpy(y[[3]]), tensor_to_numpy(values[[3]]))
-  expect_equal(tensor_to_numpy(y[[4]]), tensor_to_numpy(values[[4]]))
 
   # Test that padding is not destroyed
   y_2 <- masking_layer(y[[1]])
   expect_equal(tensor_to_numpy(y[[2]]), tensor_to_numpy(y_2[[2]]))
-  expect_equal(tensor_to_numpy(y[[3]]), tensor_to_numpy(y_2[[3]]))
-  expect_equal(tensor_to_numpy(y[[4]]), tensor_to_numpy(y_2[[4]]))
 })
+
 # Residual connection with Mask-----------------------------------------------------------
 test_that("residual connection with Mask", {
   device <- ifelse(torch$cuda$is_available(), "cuda", "cpu")
@@ -165,37 +163,27 @@ test_that("residual connection with Mask", {
     y <- layer(
       x = values[[1]],
       y = values[[1]],
-      seq_len = values[[2]],
-      mask_times = values[[3]],
-      mask_features = values[[4]]
+      mask_times = values[[2]]
     )
     layer$eval()
 
     # Test that masking values are the same
     expect_equal(tensor_to_numpy(y[[2]]), tensor_to_numpy(values[[2]]))
-    expect_equal(tensor_to_numpy(y[[3]]), tensor_to_numpy(values[[3]]))
-    expect_equal(tensor_to_numpy(y[[4]]), tensor_to_numpy(values[[4]]))
 
     # Test that padding is not destroyed
     y_2 <- masking_layer(y[[1]])
     expect_equal(tensor_to_numpy(y[[2]]), tensor_to_numpy(y_2[[2]]))
-    expect_equal(tensor_to_numpy(y[[3]]), tensor_to_numpy(y_2[[3]]))
-    expect_equal(tensor_to_numpy(y[[4]]), tensor_to_numpy(y_2[[4]]))
 
     # Test that values do not change at random for same input
     y_1 <- layer(
       x = values[[1]],
       y = values[[1]],
-      seq_len = values[[2]],
-      mask_times = values[[3]],
-      mask_features = values[[4]]
+      mask_times = values[[2]]
     )
     y_2 <- layer(
       x = values[[1]],
       y = values[[1]],
-      seq_len = values[[2]],
-      mask_times = values[[3]],
-      mask_features = values[[4]]
+      mask_times = values[[2]]
     )
     expect_equal(tensor_to_numpy(y_1[[1]]), tensor_to_numpy(y_2[[1]]))
   }
@@ -224,21 +212,15 @@ test_that("LayerNorm with Mask", {
   )$to(device)
   y <- layer(
     x = values[[1]],
-    seq_len = values[[2]],
-    mask_times = values[[3]],
-    mask_features = values[[4]]
+    mask_times = values[[2]]
   )
 
   # Test that masking values are the same
   expect_equal(tensor_to_numpy(y[[2]]), tensor_to_numpy(values[[2]]))
-  expect_equal(tensor_to_numpy(y[[3]]), tensor_to_numpy(values[[3]]))
-  expect_equal(tensor_to_numpy(y[[4]]), tensor_to_numpy(values[[4]]))
 
   # Test that padding is not destroyed
   y_2 <- masking_layer(y[[1]])
   expect_equal(tensor_to_numpy(y[[2]]), tensor_to_numpy(y_2[[2]]))
-  expect_equal(tensor_to_numpy(y[[3]]), tensor_to_numpy(y_2[[3]]))
-  expect_equal(tensor_to_numpy(y[[4]]), tensor_to_numpy(y_2[[4]]))
 
   # Test that the computations are correct for sequences with full length
   example_tensor <- generate_tensors(
@@ -260,13 +242,177 @@ test_that("LayerNorm with Mask", {
 
   results <- tensor_to_numpy(layer(
     x = values[[1]],
-    seq_len = values[[2]],
-    mask_times = values[[3]],
-    mask_features = values[[4]]
+    mask_times = values[[2]],
   )[[1]])
   expect_equal(results, res_expected, tolerance = 1e-5)
 })
 
+# BatchNorm with Mask-----------------------------------------------------------
+test_that("BatchNorm with Mask", {
+  device <- ifelse(torch$cuda$is_available(), "cuda", "cpu")
+  pad_value <- sample(x = seq(from = -200, to = -10, by = 10), size = 1)
+  times <- sample(x = seq(from = 3, to = 10, by = 1), size = 1)
+  features <- sample(x = seq(from = 3, to = 1024, by = 1), size = 1)
+  sequence_length <- sample(x = seq(from = 1, to = times, by = 1), size = 30, replace = TRUE)
+  example_tensor <- generate_tensors(
+    times = times,
+    features = features,
+    seq_len = sequence_length,
+    pad_value = pad_value
+  )$to(device)
+  masking_layer <- py$masking_layer(pad_value)$to(device)
+  values <- masking_layer(example_tensor)
+
+  layer <- py$BatchNorm_with_Mask(
+    features = as.integer(features),
+    pad_value = as.integer(pad_value),
+    alpha=0.1,
+    eps = 1e-05
+  )$to(device)
+  layer$eval()
+  y <- layer(
+    x = values[[1]],
+    mask_times = values[[2]]
+  )
+
+  # Test that masking values are the same
+  expect_equal(tensor_to_numpy(y[[2]]), tensor_to_numpy(values[[2]]))
+
+  # Test that padding is not destroyed
+  y_2 <- masking_layer(y[[1]])
+  expect_equal(tensor_to_numpy(y[[2]]), tensor_to_numpy(y_2[[2]]))
+
+  # Test that the computations are correct for sequences with full length
+  example_tensor <- generate_tensors(
+    times = times,
+    features = features,
+    seq_len = rep.int(times, times = 10),
+    pad_value = pad_value
+  )$to(device)
+  comparison_layer <- torch$nn$BatchNorm1d(
+    num_features = example_tensor$size(2L),
+    eps = 1e-05,
+    affine = TRUE,
+    momentum=0.1,
+    track_running_stats=TRUE,
+    device = NULL,
+    dtype = example_tensor$dtype
+  )$to(device)
+  comparison_layer$eval()
+  res_expected <- tensor_to_numpy(
+    torch$permute(
+      comparison_layer(
+        torch$permute(
+          example_tensor,reticulate::tuple(list(0L,2L,1L))
+        )
+      ),
+      reticulate::tuple(list(0L,2L,1L))
+    )
+  )
+  values <- masking_layer(example_tensor)
+
+  results <- tensor_to_numpy(layer(
+    x = values[[1]],
+    mask_times = values[[2]]
+  )[[1]])
+  expect_equal(results, res_expected, tolerance = 1e-4)
+})
+
+# RMSNorm with Mask-----------------------------------------------------------
+test_that("RMSNorm with Mask", {
+  device <- ifelse(torch$cuda$is_available(), "cuda", "cpu")
+  pad_value <- sample(x = seq(from = -200, to = -10, by = 10), size = 1)
+  times <- sample(x = seq(from = 3, to = 10, by = 1), size = 1)
+  features <- sample(x = seq(from = 3, to = 1024, by = 1), size = 1)
+  sequence_length <- sample(x = seq(from = 1, to = times, by = 1), size = 30, replace = TRUE)
+  example_tensor <- generate_tensors(
+    times = times,
+    features = features,
+    seq_len = sequence_length,
+    pad_value = pad_value
+  )$to(device)
+  masking_layer <- py$masking_layer(pad_value)$to(device)
+  values <- masking_layer(example_tensor)
+
+  layer <- py$RMSNorm_with_Mask(
+    features = as.integer(features),
+    pad_value = as.integer(pad_value)
+  )$to(device)
+  y <- layer(
+    x = values[[1]],
+    mask_times = values[[2]],
+  )
+
+  # Test that masking values are the same
+  expect_equal(tensor_to_numpy(y[[2]]), tensor_to_numpy(values[[2]]))
+
+  # Test that padding is not destroyed
+  y_2 <- masking_layer(y[[1]])
+  expect_equal(tensor_to_numpy(y[[2]]), tensor_to_numpy(y_2[[2]]))
+
+
+  # Test that the computations are correct for sequences with full length
+  #example_tensor <- generate_tensors(
+  #  times = times,
+  #  features = features,
+  #  seq_len = rep.int(times, times = 10),
+  #  pad_value = pad_value
+  #)$to(device)
+  #comparison_layer <- torch.nn.RMSNorm(
+  #  normalized_shape = example_tensor$size(2L),
+  #  eps = 1e-05,
+  #  elementwise_affine = TRUE,
+  #  device = NULL,
+  #  dtype = example_tensor$dtype
+  #)$to(device)
+  #res_expected <- tensor_to_numpy(comparison_layer(example_tensor))
+  #values <- masking_layer(example_tensor)
+
+  #results <- tensor_to_numpy(layer(
+  #  x = values[[1]],
+  #  seq_len = values[[2]],
+  #  mask_times = values[[3]],
+  #  mask_features = values[[4]]
+  #)[[1]])
+  #expect_equal(results, res_expected, tolerance = 1e-5)
+})
+
+#PowerNorm with mask-----------------------------------------------------------
+test_that("PowerNorm with Mask", {
+  device <- ifelse(torch$cuda$is_available(), "cuda", "cpu")
+  pad_value <- sample(x = seq(from = -200, to = -10, by = 10), size = 1)
+  times <- sample(x = seq(from = 3, to = 10, by = 1), size = 1)
+  features <- sample(x = seq(from = 3, to = 1024, by = 1), size = 1)
+  sequence_length <- sample(x = seq(from = 1, to = times, by = 1), size = 30, replace = TRUE)
+  example_tensor <- generate_tensors(
+    times = times,
+    features = features,
+    seq_len = sequence_length,
+    pad_value = pad_value
+  )$to(device)
+  masking_layer <- py$masking_layer(pad_value)$to(device)
+  values <- masking_layer(example_tensor)
+
+  layer <- py$PowerNorm_with_Mask(
+    features = as.integer(features),
+    pad_value = as.integer(pad_value),
+    alpha=0.9,
+    eps = 1e-05
+  )$to(device)
+  layer$eval()
+  y <- layer(
+    x = values[[1]],
+    mask_times = values[[2]]
+  )
+
+  # Test that masking values are the same
+  expect_equal(tensor_to_numpy(y[[2]]), tensor_to_numpy(values[[2]]))
+
+  # Test that padding is not destroyed
+  y_2 <- masking_layer(y[[1]])
+  expect_equal(tensor_to_numpy(y[[2]]), tensor_to_numpy(y_2[[2]]))
+})
+
 # Dense Layer with Mask-----------------------------------------------------------
 test_that("DenseLayer with Mask", {
   device <- ifelse(torch$cuda$is_available(), "cuda", "cpu")
@@ -315,36 +461,24 @@ test_that("DenseLayer with Mask", {
 
           y <- layer(
             x = values[[1]],
-            seq_len = values[[2]],
-            mask_times = values[[3]],
-            mask_features = values[[4]]
+            mask_times = values[[2]]
           )
 
           # Test that masking values are the same
           expect_equal(tensor_to_numpy(y[[2]]), tensor_to_numpy(values[[2]]))
-          expect_equal(tensor_to_numpy(y[[3]]), tensor_to_numpy(values[[3]]))
-
-          # Test the correct size of the new masking on feature level
-          expect_equal(dim(tensor_to_numpy(y[[4]]))[3], target_features)
 
           # Test that padding is not destroyed
           y_2 <- masking_layer(y[[1]])
           expect_equal(tensor_to_numpy(y[[2]]), tensor_to_numpy(y_2[[2]]))
-          expect_equal(tensor_to_numpy(y[[3]]), tensor_to_numpy(y_2[[3]]))
-          expect_equal(tensor_to_numpy(y[[4]]), tensor_to_numpy(y_2[[4]]))
 
           # Test that values do not change at random for same input
           y_1 <- layer(
             x = values[[1]],
-            seq_len = values[[2]],
-            mask_times = values[[3]],
-            mask_features = values[[4]]
+            mask_times = values[[2]]
           )
           y_2 <- layer(
             x = values[[1]],
-            seq_len = values[[2]],
-            mask_times = values[[3]],
-            mask_features = values[[4]]
+            mask_times = values[[2]]
           )
           expect_equal(tensor_to_numpy(y_1[[1]]), tensor_to_numpy(y_2[[1]]))
         }
@@ -405,33 +539,24 @@ test_that("layer_tf_encoder", {
 
         y <- layer(
           x = values[[1]],
-          seq_len = values[[2]],
-          mask_times = values[[3]],
-          mask_features = values[[4]]
+          mask_times = values[[2]]
         )
 
         # Test that masking values are the same
         expect_equal(tensor_to_numpy(y[[2]]), tensor_to_numpy(values[[2]]))
-        expect_equal(tensor_to_numpy(y[[3]]), tensor_to_numpy(values[[3]]))
 
         # Test that padding is not destroyed
         y_2 <- masking_layer(y[[1]])
         expect_equal(tensor_to_numpy(y[[2]]), tensor_to_numpy(y_2[[2]]))
-        expect_equal(tensor_to_numpy(y[[3]]), tensor_to_numpy(y_2[[3]]))
-        expect_equal(tensor_to_numpy(y[[4]]), tensor_to_numpy(y_2[[4]]))
 
         # Test that values do not change at random for same input
         y_1 <- layer(
           x = values[[1]],
-          seq_len = values[[2]],
-          mask_times = values[[3]],
-          mask_features = values[[4]]
+          mask_times = values[[2]]
         )
         y_2 <- layer(
           x = values[[1]],
-          seq_len = values[[2]],
-          mask_times = values[[3]],
-          mask_features = values[[4]]
+          mask_times = values[[2]]
         )
         expect_equal(tensor_to_numpy(y_1[[1]]), tensor_to_numpy(y_2[[1]]))
       }
@@ -462,7 +587,7 @@ test_that("exreme_pooling_over_time", {
       pad_value = as.integer(pad_value),
       pooling_type = pooling_type
     )$to(device)
-    y_1 <- layer(values[[1]], values[[4]])
+    y_1 <- layer(values[[1]], py$get_FeatureMask_from_mask(values[[2]],as.integer(features)))
     if (pooling_type != "MinMax") {
       expect_equal(dim(tensor_to_numpy(y_1)), c(length(sequence_length), features))
     } else {
@@ -550,36 +675,24 @@ test_that("layer_n_gram_convolution", {
 
   y <- layer(
     x = values[[1]],
-    seq_len = values[[2]],
-    mask_times = values[[3]],
-    mask_features = values[[4]]
+    mask_times = values[[2]]
   )
 
   # Test that masking values are the same
   expect_equal(tensor_to_numpy(y[[2]]), tensor_to_numpy(values[[2]]))
-  expect_equal(tensor_to_numpy(y[[3]]), tensor_to_numpy(values[[3]]))
-
-  # Test the correct size of the new masking on feature level
-  expect_equal(dim(tensor_to_numpy(y[[4]]))[3], n_filter)
 
   # Test that padding is not destroyed
   y_2 <- masking_layer(y[[1]])
   expect_equal(tensor_to_numpy(y[[2]]), tensor_to_numpy(y_2[[2]]))
-  expect_equal(tensor_to_numpy(y[[3]]), tensor_to_numpy(y_2[[3]]))
-  expect_equal(tensor_to_numpy(y[[4]]), tensor_to_numpy(y_2[[4]]))
 
   # Test that values do not change at random for same input
   y_1 <- layer(
     x = values[[1]],
-    seq_len = values[[2]],
-    mask_times = values[[3]],
-    mask_features = values[[4]]
+    mask_times = values[[2]]
   )
   y_2 <- layer(
     x = values[[1]],
-    seq_len = values[[2]],
-    mask_times = values[[3]],
-    mask_features = values[[4]]
+    mask_times = values[[2]]
   )
   expect_equal(tensor_to_numpy(y_1[[1]]), tensor_to_numpy(y_2[[1]]))
 
@@ -620,36 +733,24 @@ test_that("layer_mutiple_n_gram_convolution", {
 
     y <- layer(
       x = values[[1]],
-      seq_len = values[[2]],
-      mask_times = values[[3]],
-      mask_features = values[[4]]
+      mask_times = values[[2]]
     )
 
     # Test that masking values are the same
     expect_equal(tensor_to_numpy(y[[2]]), tensor_to_numpy(values[[2]]))
-    expect_equal(tensor_to_numpy(y[[3]]), tensor_to_numpy(values[[3]]))
-
-    # Test the correct size of the new masking on feature level
-    expect_equal(dim(tensor_to_numpy(y[[4]]))[3], features)
 
     # Test that padding is not destroyed
     y_2 <- masking_layer(y[[1]])
     expect_equal(tensor_to_numpy(y[[2]]), tensor_to_numpy(y_2[[2]]))
-    expect_equal(tensor_to_numpy(y[[3]]), tensor_to_numpy(y_2[[3]]))
-    expect_equal(tensor_to_numpy(y[[4]]), tensor_to_numpy(y_2[[4]]))
 
     # Test that values do not change at random for same input
     y_1 <- layer(
       x = values[[1]],
-      seq_len = values[[2]],
-      mask_times = values[[3]],
-      mask_features = values[[4]]
+      mask_times = values[[2]]
     )
     y_2 <- layer(
       x = values[[1]],
-      seq_len = values[[2]],
-      mask_times = values[[3]],
-      mask_features = values[[4]]
+      mask_times = values[[2]]
     )
     expect_equal(tensor_to_numpy(y_1[[1]]), tensor_to_numpy(y_2[[1]]))
 
@@ -694,9 +795,7 @@ test_that("merge_layer", {
 
       y <- layer(
         tensor_list = rep(values[1], times = n_input_streams),
-        seq_len = values[[2]],
-        mask_times = values[[3]],
-        mask_features = values[[4]]
+        mask_times = values[[2]]
       )
 
       # Test the correct shape
@@ -733,29 +832,19 @@ test_that("rnn_preparation", {
 
   y <- layer_do(
     x = values[[1]],
-    seq_len = values[[2]],
-    mask_times = values[[3]],
-    mask_features = values[[4]]
+    mask_times = values[[2]]
   )
   y <- layer_undo(
     x = y[[1]],
-    seq_len = y[[2]],
-    mask_times = y[[3]],
-    mask_features = y[[4]]
+    mask_times = y[[2]]
   )
 
   # Test that masking values are the same
   expect_equal(tensor_to_numpy(y[[2]]), tensor_to_numpy(values[[2]]))
-  expect_equal(tensor_to_numpy(y[[3]]), tensor_to_numpy(values[[3]]))
-
-  # Test the correct size of the new masking on feature level
-  expect_equal(dim(tensor_to_numpy(y[[4]]))[3], features)
 
   # Test that padding is not destroyed
   y_2 <- masking_layer(y[[1]])
   expect_equal(tensor_to_numpy(y[[2]]), tensor_to_numpy(y_2[[2]]))
-  expect_equal(tensor_to_numpy(y[[3]]), tensor_to_numpy(y_2[[3]]))
-  expect_equal(tensor_to_numpy(y[[4]]), tensor_to_numpy(y_2[[4]]))
 })
 
 test_that("layer_class_mean", {
@@ -822,7 +911,10 @@ test_that("layer_global_average_pooling_1d", {
 
   layer <- py$layer_global_average_pooling_1d(mask_type = "mask")$to(device)
 
-  results <- layer(x = values[[1]], mask = values[[3]])
+  results <- layer(
+    x = values[[1]],
+    mask =values[[2]]
+  )
 
   true_mean_source <- tensor_to_numpy(example_tensor)
   true_mean_source <- replace(x = true_mean_source, true_mean_source == pad_value, values = 0)
